<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl" sourcelanguage="en">
<context>
    <name>Board</name>
    <message>
        <source>Details</source>
        <translation>Details</translation>
    </message>
    <message>
        <source>Guess</source>
        <translation>Raden</translation>
    </message>
    <message>
        <source>Found</source>
        <translation>Gevonden</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normaal</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Groot</translation>
    </message>
    <message>
        <source>Missed</source>
        <translation>Gemist</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <source>Success</source>
        <translation>Het spel is voltooid</translation>
    </message>
    <message>
        <source>Game Over</source>
        <translation>Het spel is afgelopen</translation>
    </message>
    <message numerus="yes">
        <source>%1 of %n point(s)</source>
        <translation>
            <numerusform>%1 van %n punt</numerusform>
            <numerusform>%1 van %n punten</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>3 of %n point(s)</source>
        <translation>
            <numerusform>3 van %n punt</numerusform>
            <numerusform>3 van %n punten</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>2 of %n point(s)</source>
        <translation>
            <numerusform>2 van %n punt</numerusform>
            <numerusform>2 van %n punten</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>1 of %n point(s)</source>
        <translation>
            <numerusform>1 van %n punt</numerusform>
            <numerusform>1 van %n punten</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>0 of %n point(s)</source>
        <translation>
            <numerusform>0 van %n punt</numerusform>
            <numerusform>0 van %n punten</numerusform>
        </translation>
    </message>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation>
            <numerusform>%n punt</numerusform>
            <numerusform>%n punten</numerusform>
        </translation>
    </message>
    <message>
        <source>The maximum score was calculated from the following thirty words:</source>
        <translation>De maximumscore is gebaseerd op de volgende dertig woorden:</translation>
    </message>
</context>
<context>
    <name>Clock</name>
    <message>
        <source>m:ss</source>
        <translation>m:ss</translation>
    </message>
    <message numerus="yes">
        <source>%n guesses(s)</source>
        <translation>
            <numerusform>%n keer geraden</numerusform>
            <numerusform>%n keer geraden</numerusform>
        </translation>
    </message>
    <message>
        <source>+%1</source>
        <translation>+%1</translation>
    </message>
    <message numerus="yes">
        <source>%n strike(s)</source>
        <translation>
            <numerusform>%n misser</numerusform>
            <numerusform>%n missers</numerusform>
        </translation>
    </message>
    <message>
        <source>Tanglet</source>
        <translation>Stijgende lijn</translation>
    </message>
    <message>
        <source>Classic</source>
        <translation>Vertrouwd</translation>
    </message>
    <message>
        <source>Refill</source>
        <translation>Terug bij af</translation>
    </message>
    <message>
        <source>Stamina</source>
        <translation>Respijt</translation>
    </message>
    <message>
        <source>Strikeout</source>
        <translation>Scheepsrecht</translation>
    </message>
    <message>
        <source>Allotment</source>
        <translation>Hoge ogen</translation>
    </message>
    <message>
        <source>Discipline</source>
        <translation>Vriezen of dooien</translation>
    </message>
    <message>
        <source>Unlimited</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases on correct guesses.</source>
        <translation>Begint op 30 seconden, neemt toe bij een goed antwoord.</translation>
    </message>
    <message>
        <source>Counts down from 3 minutes.</source>
        <translation>Duurt 3 minuten.</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and refills on correct guesses.</source>
        <translation>Begint op 30 seconden, herstart bij een goed antwoord.</translation>
    </message>
    <message>
        <source>Counts down from 45 seconds and pauses on correct guesses.</source>
        <translation>Begint op 45 seconden, wordt bij een goed antwoord even stilgezet.</translation>
    </message>
    <message>
        <source>Game ends after 3 incorrect guesses.</source>
        <translation>Stopt na 3 keer verkeerd raden.</translation>
    </message>
    <message>
        <source>Game ends after 30 guesses.</source>
        <translation>Stopt na 30 keer raden.</translation>
    </message>
    <message>
        <source>Counts down from 30 seconds and increases or decreases on guesses.</source>
        <translation>Begint op 30 seconden, neemt toe of af afhankelijk van het antwoord.</translation>
    </message>
    <message>
        <source>Game ends when all words are found.</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>Generator</name>
    <message>
        <source>Unable to read dice from file.</source>
        <translation>Kan de dobbelsteen niet uit het bestand uitlezen.</translation>
    </message>
    <message>
        <source>Unable to read word list from file.</source>
        <translation>Kan de woordenlijst niet uit het bestand uitlezen.</translation>
    </message>
</context>
<context>
    <name>LanguageDialog</name>
    <message>
        <source>Board Language</source>
        <translation>Taal van het bord</translation>
    </message>
    <message>
        <source>Custom</source>
        <translation>Aangepast</translation>
    </message>
    <message>
        <source>Choose...</source>
        <translation>Kiezen...</translation>
    </message>
    <message>
        <source>&lt;b&gt;Note:&lt;/b&gt; These settings will take effect when you start a new game.</source>
        <translation>&lt;b&gt;Opmerking:&lt;/b&gt; Deze instellingen worden van kracht zodra een nieuw spel gestart wordt.</translation>
    </message>
    <message>
        <source>Language:</source>
        <translation>Taal:</translation>
    </message>
    <message>
        <source>Dice:</source>
        <translation>Dobbelsteen:</translation>
    </message>
    <message>
        <source>Word list:</source>
        <translation>Woordenlijst:</translation>
    </message>
    <message>
        <source>Dictionary:</source>
        <translation>Woordenboek:</translation>
    </message>
    <message>
        <source>Choose Dice File</source>
        <translation>Dobbelsteenbestand kiezen</translation>
    </message>
    <message>
        <source>Choose Word List File</source>
        <translation>Woordenlijstbestand kiezen</translation>
    </message>
</context>
<context>
    <name>LocaleDialog</name>
    <message>
        <source>Select application language:</source>
        <translation>Programmataal selecteren:</translation>
    </message>
    <message>
        <source>&lt;System Language&gt;</source>
        <translation>&lt;Systeemtaal&gt;</translation>
    </message>
    <message>
        <source>Note</source>
        <translation>Opmerking</translation>
    </message>
    <message>
        <source>Please restart this application for the change in language to take effect.</source>
        <translation>U dient het programma opnieuw te starten om de taalwijziging toe te passen.</translation>
    </message>
</context>
<context>
    <name>NewGameDialog</name>
    <message>
        <source>New Game</source>
        <translation>Nieuw spel</translation>
    </message>
    <message>
        <source>Amount of Words:</source>
        <translation>Aantal woorden:</translation>
    </message>
    <message>
        <source>Minimum Word Length:</source>
        <translation>Minimale woordlengte:</translation>
    </message>
    <message>
        <source>Low</source>
        <translation>Laag</translation>
    </message>
    <message>
        <source>Medium</source>
        <translation>Gemiddeld</translation>
    </message>
    <message>
        <source>High</source>
        <translation>Hoog</translation>
    </message>
    <message>
        <source>Random</source>
        <translation>Willekeurig</translation>
    </message>
    <message numerus="yes">
        <source>%n letter(s)</source>
        <translation>
            <numerusform>%n letter</numerusform>
            <numerusform>%n letters</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>ScoresDialog</name>
    <message>
        <source>High Scores</source>
        <translation>Topscores</translation>
    </message>
    <message>
        <source>Rank</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Name</source>
        <translation>Naam</translation>
    </message>
    <message>
        <source>Score</source>
        <translation>Score</translation>
    </message>
    <message>
        <source>Maximum</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Date</source>
        <translation>Datum</translation>
    </message>
    <message>
        <source>Size</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Congratulations!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You beat your top score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>Well done!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>You have a new high score!</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>N/A</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <source>#%1</source>
        <translation>%1</translation>
    </message>
</context>
<context>
    <name>Window</name>
    <message>
        <source>Tanglet</source>
        <translation>Tanglet</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Paused&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Click to resume playing.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Gepauzeerd&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Klik om verder te spelen.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Loading game...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Even geduld&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Bezig met laden van het spel...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Click to start a new game.</source>
        <translation>Klik om een nieuw spel te starten.</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Generating a new board...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Even geduld&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Bezig met aanmaken van een nieuw bord...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Please wait&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Optimizing word list...&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Even geduld&lt;/big&gt;&lt;/b&gt;&lt;br&gt;Bezig met optimaliseren van de woordenlijst...&lt;/p&gt;</translation>
    </message>
    <message>
        <source>&amp;Game</source>
        <translation>&amp;Spel</translation>
    </message>
    <message>
        <source>New &amp;Game...</source>
        <translation>&amp;Nieuw spel...</translation>
    </message>
    <message>
        <source>Ctrl+Shift+N</source>
        <translation>Ctrl+Shift+N</translation>
    </message>
    <message>
        <source>&amp;New Roll</source>
        <translation>&amp;Opnieuw dobbelen</translation>
    </message>
    <message>
        <source>&amp;Choose...</source>
        <translation>&amp;Kiezen...</translation>
    </message>
    <message>
        <source>&amp;Share...</source>
        <translation>D&amp;elen...</translation>
    </message>
    <message>
        <source>&amp;End</source>
        <translation>&amp;Stoppen</translation>
    </message>
    <message>
        <source>&amp;Pause</source>
        <translation>&amp;Pauzeren</translation>
    </message>
    <message>
        <source>Ctrl+P</source>
        <translation>Ctrl+P</translation>
    </message>
    <message>
        <source>&amp;Details</source>
        <translation>&amp;Details</translation>
    </message>
    <message>
        <source>&amp;High Scores</source>
        <translation>&amp;Topscores</translation>
    </message>
    <message>
        <source>&amp;Quit</source>
        <translation>&amp;Afsluiten</translation>
    </message>
    <message>
        <source>Ctrl+Q</source>
        <translation>Ctrl+Q</translation>
    </message>
    <message>
        <source>&amp;Settings</source>
        <translation>&amp;Instellingen</translation>
    </message>
    <message>
        <source>Show &amp;Maximum Score</source>
        <translation>&amp;Maximumscore tonen</translation>
    </message>
    <message>
        <source>&amp;Never</source>
        <translation>&amp;Nooit</translation>
    </message>
    <message>
        <source>&amp;End Of Game</source>
        <translation>Aan het &amp;einde van het spel</translation>
    </message>
    <message>
        <source>&amp;Always</source>
        <translation>&amp;Altijd</translation>
    </message>
    <message>
        <source>Show Missed &amp;Words</source>
        <translation>&amp;Gemiste woorden tonen</translation>
    </message>
    <message>
        <source>Show Word &amp;Counts</source>
        <translation>&amp;Woordentelling tonen</translation>
    </message>
    <message>
        <source>&amp;Board Language...</source>
        <translation>&amp;Taal van het bord...</translation>
    </message>
    <message>
        <source>Application &amp;Language...</source>
        <translation>&amp;Programmataal...</translation>
    </message>
    <message>
        <source>&amp;Help</source>
        <translation>&amp;Help</translation>
    </message>
    <message>
        <source>&amp;Controls</source>
        <translation>&amp;Bediening</translation>
    </message>
    <message>
        <source>&amp;About</source>
        <translation>&amp;Info</translation>
    </message>
    <message>
        <source>About &amp;Qt</source>
        <translation>Info over &amp;Qt</translation>
    </message>
    <message>
        <source>Copyright &amp;copy; 2009-%1 Graeme Gott</source>
        <translation>Copyright &amp;copy; 2009-%1 Graeme Gott</translation>
    </message>
    <message>
        <source>Tanglet %1</source>
        <translation>Tanglet %1</translation>
    </message>
    <message>
        <source>About</source>
        <translation>Info</translation>
    </message>
    <message>
        <source>A single player variant of &lt;a href=&quot;http://en.wikipedia.org/wiki/Boggle&quot;&gt;Boggle&lt;/a&gt;</source>
        <translation>Een variant van &lt;a href=&quot;http://nl.wikipedia.org/wiki/Boggle_(spel)&quot;&gt;Boggle&lt;/a&gt; voor één speler</translation>
    </message>
    <message>
        <source>Released under the &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt; license</source>
        <translation>Beschikbaar onder de &lt;a href=&quot;http://www.gnu.org/licenses/gpl.html&quot;&gt;GPL 3&lt;/a&gt;-licentie</translation>
    </message>
    <message>
        <source>English word list is based on &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; by Kevin Atkinson</source>
        <translation>Engelse woordenlijst gebaseerd op &lt;a href=&quot;http://wordlist.sourceforge.net/&quot;&gt;SCOWL&lt;/a&gt; van Kevin Atkinson</translation>
    </message>
    <message>
        <source>Hebrew word list is based on &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; by Nadav Har&apos;El and Dan Kenigsberg</source>
        <translation>Hebreeuwse woordenlijst gebaseerd op &lt;a href=&quot;http://hspell.ivrix.org.il/&quot;&gt;Hspell&lt;/a&gt; van Nadav Har&apos;El en Dan Kenigsberg</translation>
    </message>
    <message>
        <source>Import Game</source>
        <translation>Spel importeren</translation>
    </message>
    <message>
        <source>Tanglet Games (*.tanglet)</source>
        <translation>Tanglet-spellen (*.tanglet)</translation>
    </message>
    <message>
        <source>Unable to start requested game.</source>
        <translation>Kan het gevraagde spel niet starten.</translation>
    </message>
    <message>
        <source>Error</source>
        <translation>Fout</translation>
    </message>
    <message>
        <source>Export Game</source>
        <translation>Spel exporteren</translation>
    </message>
    <message>
        <source>Question</source>
        <translation>Vraag</translation>
    </message>
    <message>
        <source>End the current game?</source>
        <translation>Wilt u het huidige spel beëindigen?</translation>
    </message>
    <message>
        <source>Details</source>
        <translation>Details</translation>
    </message>
    <message>
        <source>Board Size:</source>
        <translation>Bordgrootte:</translation>
    </message>
    <message>
        <source>Normal</source>
        <translation>Normaal</translation>
    </message>
    <message>
        <source>Large</source>
        <translation>Groot</translation>
    </message>
    <message>
        <source>Word Density:</source>
        <translation>Woorddichtheid:</translation>
    </message>
    <message>
        <source>Word Length:</source>
        <translation>Woordlengte:</translation>
    </message>
    <message>
        <source>%1 or more letters</source>
        <translation>Minstens %1 letters</translation>
    </message>
    <message>
        <source>Game Type:</source>
        <translation>Speltype:</translation>
    </message>
    <message>
        <source>Description:</source>
        <translation>Omschrijving:</translation>
    </message>
    <message>
        <source>Controls</source>
        <translation>Bediening</translation>
    </message>
    <message>
        <source>&lt;p&gt;&lt;b&gt;&lt;big&gt;Mouse Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Click on the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Click on the last selected letter.&lt;br&gt;&lt;b&gt;Erase letters:&lt;/b&gt; Click on an earlier selected letter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Click twice on the first selected letter.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Keyboard Play:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Select a word:&lt;/b&gt; Type the letters of a word.&lt;br&gt;&lt;b&gt;Make a guess:&lt;/b&gt; Press Enter.&lt;br&gt;&lt;b&gt;Clear the word:&lt;/b&gt; Press Ctrl+Backspace.&lt;/p&gt;</source>
        <translation>&lt;p&gt;&lt;b&gt;&lt;big&gt;Met de muis spelen:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Een woord selecteren:&lt;/b&gt; Klik op de letters van het woord.&lt;br&gt;&lt;b&gt;Een woord raden:&lt;/b&gt; Klik op de laatste letter van het woord.&lt;br&gt;&lt;b&gt;Een letter wissen:&lt;/b&gt; Klik op een eerder geselecteerde letter.&lt;br&gt;&lt;b&gt;Een woord wissen:&lt;/b&gt; Dubbelklik op de eerste letter van het woord.&lt;/p&gt;&lt;p&gt;&lt;b&gt;&lt;big&gt;Met het toetsenbord spelen:&lt;/big&gt;&lt;/b&gt;&lt;br&gt;&lt;b&gt;Een woord selecteren:&lt;/b&gt; Typ de letters van het woord.&lt;br&gt;&lt;b&gt;Een woord raden:&lt;/b&gt; Druk op Enter.&lt;br&gt;&lt;b&gt;Een woord wissen:&lt;/b&gt; Druk op Ctrl+Backspace.&lt;/p&gt;</translation>
    </message>
    <message>
        <source>Ctrl+H</source>
        <translation type="unfinished"></translation>
    </message>
</context>
<context>
    <name>WordCounts</name>
    <message>
        <source>Letters:</source>
        <translation>Letters:</translation>
    </message>
    <message>
        <source>Found:</source>
        <translation>Gevonden:</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</source>
        <translation>%1&lt;br&gt;&lt;b&gt;%2/%3&lt;/b&gt;</translation>
    </message>
    <message>
        <source>%1&lt;br&gt;%2/%3</source>
        <translation>%1&lt;br&gt;%2/%3</translation>
    </message>
</context>
<context>
    <name>WordTree</name>
    <message numerus="yes">
        <source>%n point(s)</source>
        <translation>
            <numerusform>%n punt</numerusform>
            <numerusform>%n punten</numerusform>
        </translation>
    </message>
</context>
<context>
    <name>main</name>
    <message>
        <source>Word finding game</source>
        <translation>Woordzoek spel</translation>
    </message>
    <message>
        <source>A game file to play.</source>
        <translation>Een spelbestand om te spelen</translation>
    </message>
</context>
</TS>
